:orphan:

==========================
Object Relational Tutorial
==========================

.. admonition:: We've Moved!

    This page is the previous home of the SQLAlchemy 1.x Tutorial.  As of 2.0,
    SQLAlchemy presents a revised way of working and an all new tutorial that
    presents Core and ORM in an integrated fashion using all the latest usage
    patterns.    See :ref:`unified_tutorial`.
